==> v5.1.1.tar.gz: barker/bookie/src/app/modifiers/modifier-detail/modifier-detail.component.ts <==
import { AfterViewInit, Component, ElementRef, OnInit, ViewChild } from '@angular/core';
import { FormBuilder, FormGroup } from '@angular/forms';
import { MatDialog } from '@angular/material/dialog';
import { ActivatedRoute, Router } from '@angular/router';

import { Modifier } from '../../core/modifier';
import { ModifierCategory } from '../../core/modifier-category';
import { ToasterService } from '../../core/toaster.service';
import { ConfirmDialogComponent } from '../../shared/confirm-dialog/confirm-dialog.component';
import { ModifierService } from '../modifier.service';

@Component({
  selector: 'app-modifier-detail',
  templateUrl: './modifier-detail.component.html',
  styleUrls: ['./modifier-detail.component.css'],
})
export class ModifierDetailComponent implements OnInit, AfterViewInit {
  @ViewChild('name', { static: true }) nameElement?: ElementRef;
  form: FormGroup;
  modifierCategories: ModifierCategory[] = [];
  item: Modifier = new Modifier();

  constructor(
    private route: ActivatedRoute,
    private router: Router,
    private dialog: MatDialog,
    private fb: FormBuilder,
    private toaster: ToasterService,
    private ser: ModifierService,
  ) {
    // Create form
    this.form = this.fb.group({
      name: '',
      showInBill: '',
      price: '',
      modifierCategory: '',
      isActive: '',
    });
  }

  ngOnInit() {
    this.route.data.subscribe((value) => {
      const data = value as { item: Modifier; modifierCategories: ModifierCategory[] };
      this.modifierCategories = data.modifierCategories;
      this.showItem(data.item);
    });
  }

  showItem(item: Modifier) {
    this.item = item;
    this.form.setValue({
      name: this.item.name || '',
      showInBill: this.item.showInBill,
      price: this.item.price || '',
      isActive: this.item.isActive,
      modifierCategory: this.item.modifierCategory ? (this.item.modifierCategory.id as string) : '',
    });
  }

  ngAfterViewInit() {
    setTimeout(() => {
      if (this.nameElement !== undefined) {
        this.nameElement.nativeElement.focus();
      }
    }, 0);
  }

  save() {
    this.ser.saveOrUpdate(this.getItem()).subscribe(
      () => {
        this.toaster.show('Success', '');
        this.router.navigateByUrl('/modifiers');
      },
      (error) => {
        this.toaster.show('Danger', error.error);
      },
    );
  }

  delete() {
    this.ser.delete(this.item.id as string).subscribe(
      () => {
        this.toaster.show('Success', '');
        this.router.navigateByUrl('/modifiers');
      },
      (error) => {
        this.toaster.show('Danger', error.error);
      },
    );
  }

  confirmDelete(): void {
    const dialogRef = this.dialog.open(ConfirmDialogComponent, {
      width: '250px',
      data: { title: 'Delete Modifier?', content: 'Are you sure? This cannot be undone.' },
    });

    dialogRef.afterClosed().subscribe((result: boolean) => {
      if (result) {
        this.delete();
      }
    });
  }

  getItem(): Modifier {
    const formModel = this.form.value;
    this.item.name = formModel.name;
    this.item.showInBill = formModel.showInBill;
    this.item.price = +formModel.price;
    this.item.isActive = formModel.isActive;
    this.item.modifierCategory = new ModifierCategory({ id: formModel.modifierCategory });
    return this.item;
  }
}

==> v10.3.1.tar.gz: barker/bookie/src/app/modifiers/modifier-detail/modifier-detail.component.ts <==
import { AfterViewInit, Component, ElementRef, OnInit, ViewChild } from '@angular/core';
import { FormBuilder, FormGroup } from '@angular/forms';
import { MatDialog } from '@angular/material/dialog';
import { ActivatedRoute, Router } from '@angular/router';

import { Modifier } from '../../core/modifier';
import { ModifierCategory } from '../../core/modifier-category';
import { ToasterService } from '../../core/toaster.service';
import { ConfirmDialogComponent } from '../../shared/confirm-dialog/confirm-dialog.component';
import { ModifierService } from '../modifier.service';

@Component({
  selector: 'app-modifier-detail',
  templateUrl: './modifier-detail.component.html',
  styleUrls: ['./modifier-detail.component.css'],
})
export class ModifierDetailComponent implements OnInit, AfterViewInit {
  @ViewChild('name', { static: true }) nameElement?: ElementRef;
  form: FormGroup;
  modifierCategories: ModifierCategory[] = [];
  item: Modifier = new Modifier();

  constructor(
    private route: ActivatedRoute,
    private router: Router,
    private dialog: MatDialog,
    private fb: FormBuilder,
    private toaster: ToasterService,
    private ser: ModifierService,
  ) {
    // Create form
    this.form = this.fb.group({
      name: '',
      showInBill: '',
      price: '',
      modifierCategory: '',
      isActive: '',
    });
  }

  ngOnInit() {
    this.route.data.subscribe((value) => {
      const data = value as { item: Modifier; modifierCategories: ModifierCategory[] };
      this.modifierCategories = data.modifierCategories;
      this.showItem(data.item);
    });
  }

  showItem(item: Modifier) {
    this.item = item;
    this.form.setValue({
      name: this.item.name || '',
      showInBill: this.item.showInBill,
      price: this.item.price || '',
      isActive: this.item.isActive,
      modifierCategory: this.item.modifierCategory ? (this.item.modifierCategory.id as string) : '',
    });
  }

  ngAfterViewInit() {
    setTimeout(() => {
      if (this.nameElement !== undefined) {
        this.nameElement.nativeElement.focus();
      }
    }, 0);
  }

  save() {
    this.ser.saveOrUpdate(this.getItem()).subscribe(
      () => {
        this.toaster.show('Success', '');
        this.router.navigateByUrl('/modifiers');
      },
      (error) => {
        this.toaster.show('Error', error);
      },
    );
  }

  delete() {
    this.ser.delete(this.item.id as string).subscribe(
      () => {
        this.toaster.show('Success', '');
        this.router.navigateByUrl('/modifiers');
      },
      (error) => {
        this.toaster.show('Error', error);
      },
    );
  }

  confirmDelete(): void {
    const dialogRef = this.dialog.open(ConfirmDialogComponent, {
      width: '250px',
      data: { title: 'Delete Modifier?', content: 'Are you sure? This cannot be undone.' },
    });

    dialogRef.afterClosed().subscribe((result: boolean) => {
      if (result) {
        this.delete();
      }
    });
  }

  getItem(): Modifier {
    const formModel = this.form.value;
    this.item.name = formModel.name;
    this.item.showInBill = formModel.showInBill;
    this.item.price = +formModel.price;
    this.item.isActive = formModel.isActive;
    this.item.modifierCategory = new ModifierCategory({ id: formModel.modifierCategory });
    return this.item;
  }
}
